@@ -5,7 +5,7 @@
  *   Clean Author: dengen40@yahoo.com
  *
  *
- *  Copyright 2002-2005 Elysium Project (elysium-project.sourceforge.net)
+ *  Copyright 2002-2007 Elysium Project (elysium-project.sourceforge.net)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of version 2 of the GNU General Public License
@@ -1010,8 +1010,7 @@ static void draw_flat_box (GtkStyle * style,
     if (area) {
       gdk_gc_set_clip_rectangle (style->bg_gc[GTK_STATE_NORMAL], NULL);
     }
-  } else if (!strncmp ("cell_even", detail, strlen ("cell_even")) ||
-	     !strncmp ("cell_odd", detail, strlen ("cell_odd"))) {
+  } else if (DETAIL ("cell_even") || DETAIL ("cell_odd")) {
     if (state_type == GTK_STATE_SELECTED) {
       if (GTK_WIDGET_HAS_FOCUS (widget)) {
 	gdk_draw_rectangle (window, style->bg_gc[state_type], TRUE,
